import 'package:flutter/material.dart' as md;
import 'package:flutter_localizations/flutter_localizations.dart';
import 'package:flx_id_binder/flx_id_binder.dart';
import 'package:flx_id_overlay/flx_id_overlay.dart';
import 'package:flx_id_overlay/generated/l10n.dart';
import 'package:flx_ui/flx_ui.dart';

class AuthTheatre {
  static Future<TokenModel?> show({
    required BuildContext context,
    required String appId,
    required String appSecret,
    required List<AuthPermission> permissions,
    Locale? locale,
  }) async {
    await FlxId.init();
    // remove dublicates
    permissions = permissions.toSet().toList();

    // sort
    permissions.sort((a, b) => a.index - b.index);

    var result = await md.showDialog<TokenModel?>(
      context: context,
      barrierDismissible: false,
      useSafeArea: false,
      barrierColor: Colors.transparent,
      builder: (BuildContext context) => AuthDialog(
        child: FlxApp(
          delegates: [
            GlobalMaterialLocalizations.delegate,
            GlobalWidgetsLocalizations.delegate,
            GlobalCupertinoLocalizations.delegate,
            S.delegate,
          ],
          locales: [
            const Locale('en'),
            const Locale('ru'),
          ],
          themeMode: Theme.of(context).brightness == Brightness.dark
              ? md.ThemeMode.dark
              : md.ThemeMode.light,
          initialWidget: SplashScreen(
            signInfo: SignInfoTunnelModel(
              appId: appId,
              appSecret: appSecret,
              permissions: permissions,
            ),
          ),
        ),
      ),
    );

    return result;
  }
}
