import 'package:flx_id_binder/models/token_model.dart';
import 'package:flx_id_overlay/flx_id_overlay.dart';
import 'package:flx_id_overlay/generated/l10n.dart';
import 'package:flx_id_overlay/screens/sign_in/controllers/sign_in_controller.dart';
import 'package:flx_ui/flx_ui.dart';
import 'package:get/get.dart';
import 'package:page_transition/page_transition.dart';

class SignInScreen extends StatelessWidget {
  final SignInfoTunnelModel signInfo;

  const SignInScreen({
    Key? key,
    required this.signInfo,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return AuthScaffold(
      subtitle: S.of(context).signIn,
      body: GetBuilder<SignInController>(
        init: SignInController(signInfo),
        builder: (controller) => Column(
          children: [
            Spacer(),
            TextField(
              controller: controller.loginController, // INFO: Info for Ilya
              placeholder: S.of(context).email,
            ),
            SizedBox(height: 20),
            TextField(
              controller: controller.passwordController, // INFO: Info for Ilya
              placeholder: S.of(context).password,
              isConceal: true,
            ),
            Spacer(),
            controller.errorMessage != null
                ? Text(
                    controller.errorMessage!,
                    style: TextTheme.text(context).copyWith(
                      color: Colors.red,
                    ),
                  )
                : SizedBox(),
            SizedBox(height: 20),
            SpaciousButton(
              text: S.of(context).signIn,
              onTap: () => controller.onSignInButtonTap(context),
            ),
            SizedBox(height: 20),
            SpaciousButton(
              backgroundColor: ColorTheme.primary(context),
              text: S.of(context).signUp,
              onTap: () => controller.onSignUpButtonTap(context),
            ),
          ],
        ),
      ),
    );
  }
}
