import 'package:flx_id_binder/enums/enums.dart';
import 'package:flx_id_overlay/flx_id_overlay.dart';
import 'package:flx_id_overlay/generated/l10n.dart';
import 'package:flx_id_overlay/screens/sign_in_accept/views/views.dart';
import 'package:flx_ui/flx_ui.dart';
import 'package:get/get.dart';

class SignInAcceptScreen extends StatelessWidget {
  final SignInfoTunnelModel signInfo;
  final AppInfoTunnelModel appInfo;

  const SignInAcceptScreen({
    Key? key,
    required this.signInfo,
    required this.appInfo,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Padding(
        padding: EdgeInsets.all(20),
        child: GetBuilder<SignInAcceptController>(
          init: SignInAcceptController(signInfo),
          builder: (controller) => Column(
            children: [
              Spacer(),
              FlatCard(
                width: 100,
                height: 100,
                child: ClipRRect(
                  borderRadius: BorderRadius.circular(11),
                  child: Image.memory(
                    appInfo.info.logoPicture,
                    fit: BoxFit.cover,
                  ),
                ),
              ),
              SizedBox(height: 20),
              Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  appInfo.info.trusted
                      ? SizedBox(
                          width: 23,
                        )
                      : SizedBox(),
                  Text(
                    ' ${appInfo.info.name} ${S.of(context).appPrefix} ',
                    style: TextTheme.subtitle(context),
                  ),
                  appInfo.info.trusted
                      ? Icon(
                          Icons.check_circle_rounded,
                          color: Colors.blue,
                          size: 23,
                        )
                      : SizedBox(),
                ],
              ),
              SizedBox(height: 10),
              Text(
                S.of(context).wantsToAccess,
                style: TextTheme.text(context),
              ),
              Spacer(),
              SizedBox(height: 20),
              FlatCard(
                height: 200,
                child: ClipRRect(
                  borderRadius: BorderRadius.circular(11),
                  child: ListView.builder(
                      shrinkWrap: true,
                      physics: BouncingScrollPhysics(),
                      itemCount: signInfo.permissions.length,
                      itemBuilder: (context, index) {
                        var current = signInfo.permissions[index];
                        var isImp = current.index >= 4;

                        return PermissionListItem(
                          isImportant: isImp,
                          title: permissionToString(context, current),
                        );
                      }),
                ),
              ),
              SizedBox(height: 20),
              Text(
                S.of(context).acceptPermissionsText,
                style: TextTheme.caption(context),
                textAlign: TextAlign.center,
              ),
              SizedBox(height: 20),
              SpaciousButton(
                text: S.of(context).accept,
                onTap: () => controller.onAcceptButtonTap(context),
                backgroundColor: Theme.of(context).brightness == Brightness.dark
                    ? Colors.green[700]
                    : Colors.green,
              ),
              SizedBox(height: 20),
              SpaciousButton(
                text: S.of(context).discard,
                onTap: () => controller.onBackButtonTap(context),
                backgroundColor: Theme.of(context).brightness == Brightness.dark
                    ? Colors.red[900]
                    : Colors.red[700],
              ),
            ],
          ),
        ),
      ),
    );
  }

  String permissionToString(BuildContext context, AuthPermission permission) {
    var s = S.of(context);
    if (permission == AuthPermission.readNames) {
      return s.readNames;
    } else if (permission == AuthPermission.readEmail) {
      return s.readEmail;
    } else if (permission == AuthPermission.readAchievements) {
      return s.readAchievements;
    } else if (permission == AuthPermission.readApplications) {
      return s.readApps;
    } else if (permission == AuthPermission.readPhotos) {
      return s.readPhotos;
    } else if (permission == AuthPermission.readPrivacy) {
      return s.readPrivacy;
    } else if (permission == AuthPermission.managePhotos) {
      return s.managePhoto;
    } else if (permission == AuthPermission.manageNames) {
      return s.manageNames;
    } else if (permission == AuthPermission.manageApplications) {
      return s.manageApplications;
    } else if (permission == AuthPermission.managePrivacy) {
      return s.managePrivacy;
    } else if (permission == AuthPermission.permitAchievements) {
      return s.permitAchievements;
    } else if (permission == AuthPermission.permitExitFromAllDevices) {
      return s.permitExitFromAllDevices;
    } else if (permission == AuthPermission.updateEmail) {
      return s.updateEmail;
    } else if (permission == AuthPermission.updatePassword) {
      return s.updatePassword;
    } else if (permission == AuthPermission.updatePhone) {
      return 'Update user phone';
    }

    return 'Cool';
  }
}
