import 'package:flx_id_overlay/flx_id_overlay.dart';
import 'package:flx_ui/flx_ui.dart';
import 'package:get/get.dart';
import 'package:matrix4_transform/matrix4_transform.dart';

class SplashScreen extends StatelessWidget {
  final SignInfoTunnelModel signInfo;

  const SplashScreen({
    Key? key,
    required this.signInfo,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Padding(
        padding: const EdgeInsets.all(20),
        child: Center(
          child: Column(
            children: [
              Spacer(),
              GetBuilder<SplashScreenController>(
                init: SplashScreenController(context, signInfo),
                builder: (controller) => AnimatedBuilder(
                  animation: controller.animationController!,
                  builder: (context, child) => Transform(
                    transform: Matrix4Transform()
                        .scale(
                          controller.scaleAnimation!.value,
                          origin: controller.center,
                        )
                        .matrix4,
                    child: SizedBox(
                      key: controller.childKey,
                      child: child!,
                    ),
                  ),
                  child: FlatCard(
                    width: 75,
                    height: 75,
                    child: ClipRRect(
                      borderRadius: BorderRadius.circular(11),
                      child: Image.asset(
                        Theme.of(context).brightness == Brightness.dark
                            ? "assets/images/logos/logo_512wh_black.png"
                            : "assets/images/logos/logo_512wh_white.png",
                        package: "flx_id_overlay",
                      ),
                    ),
                  ),
                ),
              ),
              SizedBox(height: 20),
              Text(
                " ID",
                style: TextTheme.title(context),
              ),
              Spacer(),
              Text(
                "flx team & v0.2.0-dev & 2021",
                style: TextTheme.caption(context).copyWith(
                  color: Colors.grey[700],
                ),
              )
            ],
          ),
        ),
      ),
    );
  }
}
